==> hessian-3.5.3-sources.jar: com/caucho/hessian/io/LocaleHandle.java <==
/*
 * Copyright (c) 2001-2004 Caucho Technology, Inc.  All rights reserved.
 *
 * The Apache Software License, Version 1.1
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution, if
 *    any, must include the following acknowlegement:
 *       "This product includes software developed by the
 *        Caucho Technology (http://www.caucho.com/)."
 *    Alternately, this acknowlegement may appear in the software itself,
 *    if and wherever such third-party acknowlegements normally appear.
 *
 * 4. The names "Hessian", "Resin", and "Caucho" must not be used to
 *    endorse or promote products derived from this software without prior
 *    written permission. For written permission, please contact
 *    info@caucho.com.
 *
 * 5. Products derived from this software may not be called "Resin"
 *    nor may "Resin" appear in their names without prior written
 *    permission of Caucho Technology.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL CAUCHO TECHNOLOGY OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
 * IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * @author Scott Ferguson
 */

package com.caucho.hessian.io;

import java.util.Locale;

/**
 * Handle for a locale object.
 */
public class LocaleHandle implements HessianHandle, java.io.Serializable {
    private String value;

    public LocaleHandle(String locale)
    {
        this.value = locale;
    }

    private Object readResolve()
    {
        String s = this.value;

        if (s == null)
            return null;

        int len = s.length();
        char ch = ' ';

        int i = 0;
        for (; i < len && ('a' <= (ch = s.charAt(i)) && ch <= 'z'
            || 'A' <= ch && ch <= 'Z'
            || '0' <= ch && ch <= '9'); i++) {
        }

        String language = s.substring(0, i);
        String country = null;
        String var = null;

        if (ch == '-' || ch == '_') {
            int head = ++i;

            for (; i < len && ('a' <= (ch = s.charAt(i)) && ch <= 'z'
                || 'A' <= ch && ch <= 'Z'
                || '0' <= ch && ch <= '9'); i++) {
            }

            country = s.substring(head, i);
        }

        if (ch == '-' || ch == '_') {
            int head = ++i;

            for (; i < len && ('a' <= (ch = s.charAt(i)) && ch <= 'z'
                || 'A' <= ch && ch <= 'Z'
                || '0' <= ch && ch <= '9'); i++) {
            }

            var = s.substring(head, i);
        }

        if (var != null)
            return new Locale(language, country, var);
        else if (country != null)
            return new Locale(language, country);
        else
            return new Locale(language);
    }
}

==> hessian-4.0.4-sources.jar: com/caucho/hessian/io/LocaleHandle.java <==
/*
 * Copyright (c) 2001-2008 Caucho Technology, Inc.  All rights reserved.
 *
 * The Apache Software License, Version 1.1
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution, if
 *    any, must include the following acknowlegement:
 *       "This product includes software developed by the
 *        Caucho Technology (http://www.caucho.com/)."
 *    Alternately, this acknowlegement may appear in the software itself,
 *    if and wherever such third-party acknowlegements normally appear.
 *
 * 4. The names "Hessian", "Resin", and "Caucho" must not be used to
 *    endorse or promote products derived from this software without prior
 *    written permission. For written permission, please contact
 *    info@caucho.com.
 *
 * 5. Products derived from this software may not be called "Resin"
 *    nor may "Resin" appear in their names without prior written
 *    permission of Caucho Technology.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL CAUCHO TECHNOLOGY OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
 * IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * @author Scott Ferguson
 */

package com.caucho.hessian.io;

import java.util.Locale;

/**
 * Handle for a locale object.
 */
public class LocaleHandle implements java.io.Serializable, HessianHandle {
    private String value;

    public LocaleHandle(String locale)
    {
        this.value = locale;
    }

    private Object readResolve()
    {
        String s = this.value;

        if (s == null)
            return null;

        int len = s.length();
        char ch = ' ';

        int i = 0;
        for (; i < len && ('a' <= (ch = s.charAt(i)) && ch <= 'z'
            || 'A' <= ch && ch <= 'Z'
            || '0' <= ch && ch <= '9'); i++) {
        }

        String language = s.substring(0, i);
        String country = null;
        String var = null;

        if (ch == '-' || ch == '_') {
            int head = ++i;

            for (; i < len && ('a' <= (ch = s.charAt(i)) && ch <= 'z'
                || 'A' <= ch && ch <= 'Z'
                || '0' <= ch && ch <= '9'); i++) {
            }

            country = s.substring(head, i);
        }

        if (ch == '-' || ch == '_') {
            int head = ++i;

            for (; i < len && ('a' <= (ch = s.charAt(i)) && ch <= 'z'
                || 'A' <= ch && ch <= 'Z'
                || '0' <= ch && ch <= '9'); i++) {
            }

            var = s.substring(head, i);
        }

        if (var != null)
            return new Locale(language, country, var);
        else if (country != null)
            return new Locale(language, country);
        else
            return new Locale(language);
    }
}
